@@ -1,4 +1,4 @@
-CIest = function(Formula, Data, Term, Contrast=c(-1, 1), Alpha=0.10) 
+CIest = function(Formula, Data, Term, Contrast, conf.level=0.95) 
 {
   x = ModelMatrix(Formula, Data)
   if (!(Term %in% attr(x$terms, "term.labels"))) stop(paste("There is no term: ", Term))
@@ -12,13 +12,6 @@ CIest = function(Formula, Data, Term, Contrast=c(-1, 1), Alpha=0.10)
   L = rep(0, length(r2$coefficients))
   L[colIndex] = Contrast
 
-  Diff = est(t(L), r2)
-  t0 = qt(1 - Alpha/2, r2$DFr)
-  PE = Diff[1, "Estimate"]
-  CI = PE + c(-1, 1)*t0*Diff[1, "Std. Error"]
-
-  Result = c(PE, CI)
-  names(Result) = c("Point Estimate", "Lower Limit", "Upper Limit")
-
-  return(Result)
+  Res = est(t(L), r2)
+  return(Res)
 }
